This model of ITN based vector control was originally described in https://malariajournal.biomedcentral.com/articles/10.1186/1475-2875-6-10.
make_parameters_vc_lemenach(
pars,
tau0_frac = c(0.68/3, 2.32/3),
r = 0.56,
s = 0.03,
phi = function(t) {
0
}
)none
an environment
a numeric vector giving the proportion of time spent in host seeking/bloodfeeding and resting/oviposition
probability of mosquito being repelled upon contact with ITN
probability of mosquito successfully feeding upon contact with ITN
a function that takes a single argument t and returns the level of ITN coverage at that time