Compute derivatives for deSolve::ode or deSolve::dede using
generic methods for each model component. The arguments EIR_delta and kappa_delta are
for adding external forcing to the system from unmodeled sources. This can arise
if humans can acquire infection by traveling outside the spatial domain, and
arises for mosquitoes if traveling outside the spatial domain or are being infected
by unmodeled (non-human) sources. By default these are set to NULL and are
turned off.
xDE_diffeqn(t, y, pars, EIR_delta = NULL, kappa_delta = NULL)a list containing the vector of all state derivatives
current simulation time
state vector
an environment
a vector of values to be added to the internal EIR
a vector of values to be added to the internal kappa