Mirrors xDE_diffeqn but only includes the adult and aquatic mosquito components.
xDE_diffeqn_mosy(t, y, pars, kappa, MosyBehavior)a list containing the vector of all state derivatives
current simulation time
state vector
an environment
a vector
a list emulating the output of MosquitoBehavior for the appropriate adult mosquito model